diff --git a/src/wp-admin/comment.php b/src/wp-admin/comment.php
index ee7a514be4..bfdccd6adb 100644
--- a/src/wp-admin/comment.php
+++ b/src/wp-admin/comment.php
@@ -36,6 +36,20 @@ if ( isset( $_GET['dt'] ) ) {
 	}
 }
 
+/**
+* Prevent actions in a comment associated with `Trashed` post.
+*
+* @since 5.3.0
+*
+* @link https://core.trac.wordpress.org/ticket/37826
+*/
+$comment_id = absint( $_GET['c'] );
+$comment = get_comment( $comment_id );
+
+if ( 'trash' === get_post_status( $comment->comment_post_ID ) ) {
+        wp_die( __( 'You can&#8217;t edit this comment because the associated post is in the Trash. Please restore the post first, then try again.' ) );
+}
+
 switch ( $action ) {
 
 	case 'editcomment':
@@ -60,9 +74,6 @@ switch ( $action ) {
 		wp_enqueue_script( 'comment' );
 		require_once( ABSPATH . 'wp-admin/admin-header.php' );
 
-		$comment_id = absint( $_GET['c'] );
-
-		$comment = get_comment( $comment_id );
 		if ( ! $comment ) {
 			comment_footer_die( __( 'Invalid comment ID.' ) . sprintf( ' <a href="%s">' . __( 'Go back' ) . '</a>.', 'javascript:history.go(-1)' ) );
 		}
@@ -87,9 +98,6 @@ switch ( $action ) {
 	case 'spam':
 		$title = __( 'Moderate Comment' );
 
-		$comment_id = absint( $_GET['c'] );
-
-		$comment = get_comment( $comment_id );
 		if ( ! $comment ) {
 			wp_redirect( admin_url( 'edit-comments.php?error=1' ) );
 			die();
diff --git a/src/wp-admin/includes/class-wp-list-table.php b/src/wp-admin/includes/class-wp-list-table.php
index 3faaec691d..d83333964a 100644
--- a/src/wp-admin/includes/class-wp-list-table.php
+++ b/src/wp-admin/includes/class-wp-list-table.php
@@ -685,7 +685,19 @@ class WP_List_Table {
 				'<span aria-hidden="true">&#8212;</span><span class="screen-reader-text">%s</span>',
 				__( 'No comments' )
 			);
-			// Approved comments have different display depending on some conditions.
+		/**
+		* Remove link in the comment bubble for 'trash' post.
+		*
+		* @since 5.4.0
+		*
+		* @link https://core.trac.wordpress.org/ticket/37826
+		*/
+		} elseif ( $approved_comments && 'trash' === get_post_status( $post_id ) ) {
+			printf( '<span class="post-com-count post-com-count-approved"><span class="comment-count-approved" aria-hidden="true">%s</span><span class="screen-reader-text">%s</span></span>',
+				$approved_comments_number,
+				$pending_comments ? $approved_phrase : $approved_only_phrase
+			);
+		// Approved comments have different display depending on some conditions.
 		} elseif ( $approved_comments ) {
 			printf(
 				'<a href="%s" class="post-com-count post-com-count-approved"><span class="comment-count-approved" aria-hidden="true">%s</span><span class="screen-reader-text">%s</span></a>',
